/*	$Header: /usr/people/sam/fax/faxd/RCS/Class0.c++,v 1.5 1995/02/05 07:08:27 sam Exp $ */
/*
 * Copyright (c) 1994, 1995 Sam Leffler
 * Copyright (c) 1994, 1995 Silicon Graphics, Inc.
 * HylaFAX is a trademark of Silicon Graphics
 *
 * Permission to use, copy, modify, distribute, and sell this software and 
 * its documentation for any purpose is hereby granted without fee, provided
 * that (i) the above copyright notices and this permission notice appear in
 * all copies of the software and related documentation, and (ii) the names of
 * Sam Leffler and Silicon Graphics may not be used in any advertising or
 * publicity relating to the software without the specific, prior written
 * permission of Sam Leffler and Silicon Graphics.
 * 
 * THE SOFTWARE IS PROVIDED "AS-IS" AND WITHOUT WARRANTY OF ANY KIND, 
 * EXPRESS, IMPLIED OR OTHERWISE, INCLUDING WITHOUT LIMITATION, ANY 
 * WARRANTY OF MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE.  
 * 
 * IN NO EVENT SHALL SAM LEFFLER OR SILICON GRAPHICS BE LIABLE FOR
 * ANY SPECIAL, INCIDENTAL, INDIRECT OR CONSEQUENTIAL DAMAGES OF ANY KIND,
 * OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS,
 * WHETHER OR NOT ADVISED OF THE POSSIBILITY OF DAMAGE, AND ON ANY THEORY OF 
 * LIABILITY, ARISING OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE 
 * OF THIS SOFTWARE.
 */

/*
 * Class 0 (data) Modem Driver Interface.
 */
#include "Class0.h"
#include "ModemServer.h"
#include "class2.h"			// XXX for SERVICE_DATA

Class0Modem::Class0Modem(ModemServer& s, const ModemConfig& c)
    : ClassModem(s, c)
{
}

Class0Modem::~Class0Modem()
{
}

fxBool
Class0Modem::setupModem()
{
    if (!selectBaudRate(conf.maxRate, conf.flowControl, conf.flowControl))
	return (FALSE);
    // Query service support information
    fxStr s;
    if (doQuery(conf.classQueryCmd, s, 500) && parseRange(s, modemServices))
	traceBits(modemServices & SERVICE_ALL, serviceNames);
    if ((modemServices & SERVICE_DATA) == 0)
	return (FALSE);
    atCmd(conf.class0Cmd);

    /*
     * Query manufacturer, model, and firmware revision.
     * We use the manufacturer especially as a key to
     * working around firmware bugs (yech!).
     */
    if (setupManufacturer(modemMfr)) {
	modemCapability("Mfr " | modemMfr);
	modemMfr.raisecase();
    }
    (void) setupModel(modemModel);
    (void) setupRevision(modemRevision);
    if (modemModel != "")
	modemCapability("Model " | modemModel);
    if (modemRevision != "")
	modemCapability("Revision " | modemRevision);

    return (TRUE);
}

CallStatus
Class0Modem::dial(const char* number, fxStr& emsg)
{
    return (atCmd(conf.class0Cmd) && ClassModem::dial(number, emsg));
}

/*
 * Wait-for and process a dial command response.
 */
CallStatus
Class0Modem::dialResponse(fxStr&)
{
    switch (atResponse(rbuf, conf.dialResponseTimeout)) {
    case AT_BUSY:	return (BUSY);
    case AT_NODIALTONE:	return (NODIALTONE);
    case AT_NOANSWER:	return (NOANSWER);
    case AT_ERROR:	return (ERROR);
    case AT_CONNECT:	return (OK);
    case AT_OK:		return (NOCARRIER);
    case AT_NOCARRIER:	return (NOCARRIER);
    }
    return (FAILURE);
}

fxBool Class0Modem::isFaxModem() const		{ return FALSE; }
